@@ -48,6 +48,11 @@ from ._api import (
     patch,
     delete,
 
+    get_timeout,
+    set_timeout,
+    get_max_retries,
+    set_max_retries,
+
     get_event,
     get_events,
     dispatch_event,
@@ -245,6 +250,11 @@ __all__ = (
     "patch",
     "delete",
 
+    "get_timeout",
+    "set_timeout",
+    "get_max_retries",
+    "set_max_retries",
+
     "get_event",
     "get_events",
     "dispatch_event",
